(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[489],{223:function(e,n,t){(window.__NEXT_P=window.__NEXT_P||[]).push(["/account/upgrade",function(){return t(20717)}])},20717:function(e,n,t){"use strict";t.r(n),t.d(n,{__N_SSP:function(){return h},default:function(){return p}});var r=t(39324),o=t(35250),a=t(60554),i=t(70079),s=t(93683),u=t(88798),c=t(27986),l=t(21739),d=t(78931),f=t(50795),v=t(82081),h=!0;function p(e){return(0,o.jsx)(x,(0,r._)({},e))}function x(e){var n=e.user,t=e.isUserInCanPayGroup,r=e.serviceStatus,f=e.userCountry,v=e.cohort,h=(0,a.useRouter)(),p=(0,d.WY)(),x=(0,l.g)(function(e){return e.updateFlagValue});(0,i.useEffect)(function(){void 0!==t&&x("isUserInCanPayGroup",t)},[x,t]),(0,i.useEffect)(function(){(null==r?void 0:r.type)&&void 0!==p&&!p&&u.m.warning(r.message,{hasCloseButton:!0,duration:5})},[p,null==r?void 0:r.message,null==r?void 0:r.type]);var _={};v&&(_.email_cohort=v),(0,c.Z)("ChatGPT",n,_);var b=(0,i.useCallback)(function(){h.push("/")},[h]);return(0,o.jsx)(m,{cohort:v,userCountry:f,children:(0,o.jsx)(s.Z,{isOpen:!0,onClose:b})})}var m=function(e){var n=e.children,t=e.cohort,r=e.userCountry;return(0,i.useEffect)(function(){t&&f.o.logEvent(v.a.accountUpgradeFullpageLoaded,{content:"Email Cohort: ".concat(t),tags:["actual_location:".concat(r)]})},[t,r]),n}},45635:function(e,n,t){"use strict";t.d(n,{u:function(){return c}});var r=t(4337),o=t(35250),a=t(22444),i=t(19841);t(70079);var s=t(21389);function u(){var e=(0,r._)(["relative top-[-3px] h-2 w-2 rotate-45 transform border-r border-b border-black/10 bg-black shadow-xs"]);return u=function(){return e},e}var c=function(e){var n=e.label,t=e.side,r=e.sideOffset,s=e.withArrow,u=e.wide,c=e.size,d=void 0===c?"small":c,f=e.interactive,v=e.usePortal,h=e.className,p=e.children,x=e.delayDuration,m=e.closeOnOutsideClick,_=e.open,b=(0,o.jsxs)(a.VY,{onPointerDownOutside:void 0===m||m?void 0:function(e){return e.preventDefault()},side:void 0===t?"bottom":t,sideOffset:void 0===r?14:r,className:(0,i.Z)("relative rounded-lg border border-black/10 bg-black p-1 shadow-xs transition-opacity",void 0!==u&&u?"max-w-sm":"max-w-xs",h),children:[(0,o.jsx)("span",{className:(0,i.Z)("flex items-center whitespace-pre-wrap px-2 py-1 text-center font-medium normal-case text-white",{"text-xs":"xsmall"===d,"text-sm":"small"===d}),children:n}),(void 0===s||s)&&(0,o.jsx)(a.Eh,{asChild:!0,children:(0,o.jsx)(l,{})})]});return(0,o.jsxs)(a.fC,{delayDuration:void 0===x?300:x,disableHoverableContent:!(void 0!==f&&f),open:_,children:[(0,o.jsx)(a.xz,{asChild:!0,children:(0,o.jsx)("span",{className:h,children:p})}),void 0===v||v?(0,o.jsx)(a.h_,{children:b}):b]})},l=s.Z.div(u())}},function(e){e.O(0,[937,774,888,179],function(){return e(e.s=223)}),_N_E=e.O()}]);